Struct Color
Source pub struct Color {
pub r: u8,
pub g: u8,
pub b: u8,
pub a: Option<u8>,
}
Parses a hex string (a-f/A-F/0-9) as a Color from the &str,
ignoring surrounding whitespace.
Errors
- If a non-hex, non-whitespace character is encountered.
Parses a hex string (a-f/A-F/0-9) as a Color from the &str,
ignoring surrounding whitespace.
Panics
- If a non-hex, non-whitespace character is encountered.
Return an iterator of values that are smaller than itself.
Read more
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read moreSourceAvailable on crate feature egui only.
Converts to this type from the input type.
Converts to this type from the input type.
Converts to this type from the input type.
SourceAvailable on crate feature egui only.
Converts to this type from the input type.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.